@@ -280,6 +280,21 @@ class DataClient:
         data = pd.DataFrame(response['data'])
         return data
 
+    def get_articles(self, keyword=None, limit=None):
+        """
+        Get the latest available articles.
+        Parameters
+        - (Optional) `keyword`: A keyword to filter articles by.
+        - (Optional) `limit`: The number of articles to return. Default is maximum number of available articles.
+        """
+            
+        path = f'news/{keyword}/articles'
+        query_params = {}
+
+        response = self.__get_url(path, query_params)
+        data = response.json()['data']
+        return data
+
     def __get_url(self, path, query_params={}):
         url = self.BASE_URL + path
 
